@@ -1,7 +1,7 @@
 package Parse::PayPal::TxDetailReport;
 
-our $DATE = '2016-07-21'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2016-12-30'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -103,6 +103,7 @@ sub parse_paypal_txdetail_report {
     }
 
     my $res = [200, "OK", {
+        format => "txdetail_v11",
         transactions => [],
     }];
 
@@ -237,13 +238,13 @@ Parse::PayPal::TxDetailReport - Parse PayPal transaction detail report into data
 
 =head1 VERSION
 
-This document describes version 0.005 of Parse::PayPal::TxDetailReport (from Perl distribution Parse-PayPal-TxDetailReport), released on 2016-07-21.
+This document describes version 0.006 of Parse::PayPal::TxDetailReport (from Perl distribution Parse-PayPal-TxDetailReport), released on 2016-12-30.
 
 =head1 SYNOPSIS
 
  use Parse::PayPal::TxDetailReport qw(parse_paypal_txdetail_report);
 
- my $res = parse_paypal_txdetail_report(files => []);
+ my $res = parse_paypal_txdetail_report(files => ["part1.csv", "part2.csv"]);
 
 Sample result when there is a parse error:
 
@@ -252,6 +253,7 @@ Sample result when there is a parse error:
 Sample result when parse is successful:
 
  [200, "OK", {
+     format => "txdetail_v11",
      account_id => "...",
      report_generation_date => 1467375872,
      report_version         => 11,
@@ -273,9 +275,12 @@ Sample result when parse is successful:
 
 =head1 DESCRIPTION
 
-This module provides routine to parse PayPal transaction detail report into a
-Perl data structure. Version 11 is supported. Multiple files are supported. Both
-the tab-separated format and comma-separated (CSV) format are supported.
+PayPal provides various kinds reports which you can retrieve from their website
+under Reports menu. This module provides routine to parse PayPal transaction
+detail report (from the website under Reports > Transactions > Transactions
+detail) into a Perl data structure. Version 11 is supported. Multiple files are
+supported. Both the tab-separated format and comma-separated (CSV) format are
+supported.
 
 =head1 FUNCTIONS
 
@@ -334,6 +339,8 @@ L<https://www.paypal.com>
 Specification of transaction detail report format:
 L<https://www.paypalobjects.com/webstatic/en_US/developer/docs/pdf/PP_LRD_Gen_TransactionDetailReport.pdf>
 
+L<Parse::PayPal::TxFinderReport>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
